@@ -16,9 +16,9 @@ from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT as Navigatio
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 import copy
 import re
-import posNegEvolution.externalPlots as externalPlots
 
-from posNegEvolution.pos_neg_evolution_init import posNegEvolutionMainLoop as pnEML 
+import externalPlots as externalPlots
+from pos_neg_evolution_init import posNegEvolutionMainLoop as pnEML 
 
 disclaimer = '''Cellular/Microbial Positive and Negative Mutation Effect Evolution simulations basing on Gillespie algorithm. Copyright (C) 2022 by Jarosław Gil. 
     This program comes with ABSOLUTELY NO WARRANTY.
@@ -55,24 +55,34 @@ class mainFormat(qtWidget.QWidget):
             ax.set_xlabel("Positive mutations")
             ax.set_ylabel("Negative mutations")
         elif select == 1:
-            pos = []
-            neg = []
-            _sum = []
-            for i in mutWave:
-                if i[0] + i[1] not in _sum:
-                    _sum.append(i[0]+i[1])
-                    pos.append(i[0])
-                    neg.append(i[1])
-                else:
-                    idx = _sum.index(i[0]+i[1])
-                    pos[idx] = pos[idx] + i[0]
-                    neg[idx] = neg[idx] + i[1]
-                    
-            ax.bar(_sum, pos)
-            ax.bar(_sum, neg, bottom=pos)  
-            ax.set_title("Population: %i, ID: %s" % (len(mutWave[:,0]), ID))
+            data = []
+            size = 0
+            if len([mutWave[0]]) == 1:
+                data = pd.DataFrame(mutWave)
+                ax.hist(data)
+                size = len(mutWave)
+            else:
+                temp = mutWave[:,0] + mutWave[:,1]
+                _max = max(temp)
+                _min = min(temp)
+                data = np.zeros((_max-_min+1, 3))
+                data[:,2] = [x for x in range(_min, _max+1)]
+                for x in mutWave:
+                    data[x[0],0] = data[x[0],0] + 1
+                    data[x[1],1] = data[x[1],1] + 1
+                data = pd.DataFrame(data)
+                data.columns = ["positive", "negative", "place"]
+                ax = data.plot.bar(x="place", stacked = True)
+                size = len(mutWave[:,0])                    
+
+            ax.set_title("Population: %i, ID: %s" % (size, ID))
             ax.set_xlabel("Mutation number")
             ax.set_ylabel("Cells number")
+        elif select == 2:
+            ax.hist(mutWave)
+            ax.set_title("Population: %i, ID: %s" % (len(mutWave), ID))
+            ax.set_xlabel("Fitness")
+            ax.set_ylabel("Cells number")
             
         self._canvas.draw()
         self.status.setText(ID + ": PLOTTED")
@@ -92,6 +102,9 @@ class mainFormat(qtWidget.QWidget):
                 elif data[0] == '-2':
                     status.setText(data[1] + ": mutation wave")
                     self.plot(data[1], data[2], 1)
+                elif data[0] == '-3':
+                    status.setText(data[1] + ": fitness wave")
+                    self.plot(data[1], data[2], 2)
                 else:
                     q.put(data)
                     
@@ -196,10 +209,22 @@ class mainFormat(qtWidget.QWidget):
         layout.addWidget(self.tabs)
         layout.addStretch()
         
-        self._VAF = qtWidget.QCheckBox("Checked: Include VAF")
+        self._NONE = qtWidget.QRadioButton("Checked: Normal simulation")       
+        self._VAF = qtWidget.QRadioButton("Checked: Include VAF")        
+        self._analytical = qtWidget.QRadioButton("Checked: Analytical model (omit VAF)")               
+        self._one_effect = qtWidget.QRadioButton("Checked: Positive mutation only (value > 0) or negative mutation only (value < 0)")     
+        
+        self._NONE.click()
+        
+        _group = qtWidget.QButtonGroup()         
+        _group.addButton(self._NONE)
+        _group.addButton(self._VAF)
+        _group.addButton(self._analytical)
+        _group.addButton(self._one_effect)
+        layout.addWidget(self._NONE)
         layout.addWidget(self._VAF)
-        self._analytical = qtWidget.QCheckBox("Checked: Analytical model (omit VAF)")
-        layout.addWidget(self._analytical)        
+        layout.addWidget(self._analytical) 
+        layout.addWidget(self._one_effect) 
         
         start = qtWidget.QPushButton(self)
         start.setText("Start simulation")
@@ -248,6 +273,7 @@ class mainFormat(qtWidget.QWidget):
     
     def cloneHistAction(self):
         fname = qtWidget.QFileDialog.getOpenFileNames(None, 'Open file', "Z://","Data File (*.npz)")[0] 
+        select = 0 + 1*self._VAF.isChecked() + 2*self._analytical.isChecked() + 3*self._one_effect.isChecked()
         if len(fname) == 0:
             self.showDialog("No file selected!", "Alert")
             return
@@ -255,7 +281,7 @@ class mainFormat(qtWidget.QWidget):
         for i in fname:
             name_id.append(re.findall('\d+', i)[-1])
         if all(map(lambda x: x.endswith('.npz'), fname)):
-            self._th_hist = (Thread(target=externalPlots.VAFplot, args=(fname)))
+            self._th_hist = (Thread(target=externalPlots.VAFplot, args=(fname, select)))
             # external_plots.binnedHist(fname, self._file_path.text(), name_id)
             self._th_hist.start()
             self.status.setText("mutations histograms ongoing")
@@ -263,7 +289,8 @@ class mainFormat(qtWidget.QWidget):
             self.showDialog("Wrong file/files extension. Use only one kind at time", "Alert")
             
     def mutWaveAction(self):
-        fname = qtWidget.QFileDialog.getOpenFileNames(None, 'Open file', "Z://","Data File (*.npz)")[0] 
+        fname = qtWidget.QFileDialog.getOpenFileNames(None, 'Open file', "Z://","Data File (*.npz)")[0]         
+        select = 0 + 1*self._VAF.isChecked() + 2*self._analytical.isChecked() + 3*self._one_effect.isChecked()
         if len(fname) == 0:
             self.showDialog("No file selected!", "Alert")
             return
@@ -271,13 +298,14 @@ class mainFormat(qtWidget.QWidget):
         for i in fname:
             name_id.append(re.findall('\d+', i)[-1])
             
-        self._th_mw = (Thread(target=externalPlots.mutationWave, args=(fname)))
+        self._th_mw = (Thread(target=externalPlots.mutationWave, args=(fname, select)))
         # external_plots.mutWavePlot(fname, self._file_path.text(), name_id)
         self._th_mw.start()
         self.status.setText("mutation wave ongoing")
     
     def fitWaveAction(self):
         fname = qtWidget.QFileDialog.getOpenFileNames(None, 'Open file', "Z://","Data File (*.npz)")[0] 
+        select = 0 + 1*self._VAF.isChecked() + 2*self._analytical.isChecked() + 3*self._one_effect.isChecked()
         if len(fname) == 0:
             self.showDialog("No file selected!", "Alert")
             return
@@ -285,7 +313,7 @@ class mainFormat(qtWidget.QWidget):
         for i in fname:
             name_id.append(re.findall('\d+', i)[-1])
             
-        self._th_fw = (Thread(target=externalPlots.fitnessWave, args=(fname)))
+        self._th_fw = (Thread(target=externalPlots.fitnessWave, args=(fname, select)))
         # external_plots.fitWavePlot(fname, self._file_path.text(), name_id)
         self._th_fw.start()
         self.status.setText("fitness wave ongoing")
@@ -391,9 +419,9 @@ class mainFormat(qtWidget.QWidget):
         self._skip.setValidator(qtGui.QDoubleValidator(0.1, 100.0, 1))
         
         self._mut_effect = qtWidget.QLineEdit(".001, -.001")
-        self._mut_effect.setInputMask("[##.#####, ##.#####]")
+        # self._mut_effect.setInputMask("[##.#####, ##.#####]")
         self._mut_prob = qtWidget.QLineEdit("0.0001, 0.05")        
-        self._mut_prob.setInputMask("[#.#####, #.#####]")
+        # self._mut_prob.setInputMask("[#.#####, #.#####]")
         
         self._lambda = qtWidget.QLineEdit(str(10))
         self._lambda.setValidator(qtGui.QIntValidator(0, 10**2))
@@ -407,7 +435,7 @@ class mainFormat(qtWidget.QWidget):
         
         _resume_button = qtWidget.QPushButton(self)
         _resume_button.setText('Resume simulation - Load File')
-        _resume_button.clicked.connect(self.resume)
+        _resume_button.clicked.connect(lambda : self.showDialog("Disabled", "Alert"))
         
         _save_params = qtWidget.QPushButton(self)
         _save_params.setText('Save Parameters')
@@ -573,6 +601,11 @@ class mainFormat(qtWidget.QWidget):
             iMuts = np.zeros(pop)
             iPop = sc.sparse.csr_matrix(np.array([iPop, iMuts]).T)
             select = 1
+        elif self._one_effect.isChecked():
+            iPop = np.ones(pop)
+            iMuts = np.zeros(pop)
+            iPop = sc.sparse.csr_matrix(np.array([iPop, iMuts]).T)
+            select = 3
         else:        
             iMuts = np.zeros(pop, dtype=np.int64).tolist()
             iProp = np.ones(pop).tolist()
