@@ -1,14 +1,16 @@
 import numpy as np
 import time
+import os
 import math
 import scipy as sc
 import pandas as pd
 from pathlib import Path  
 from threading import Thread
 
-from posNegEvolution.pos_neg_evolution_loop import posNegEvolutionLoop as PNEL
-from posNegEvolution.pos_neg_evolution_loop_VAF import posNegEvolutionLoopVAF as PNELV
-from posNegEvolution.pos_neg_analytical_model import posNegAnalyticalModel as PNAM
+from pos_neg_evolution_loop import posNegEvolutionLoop as PNEL
+from pos_neg_evolution_loop_VAF import posNegEvolutionLoopVAF as PNELV
+from pos_neg_analytical_model import posNegAnalyticalModel as PNAM
+from pos_neg_evolution_loop_one_effect import posNegEvolutionLoopOneEffect as PNOE
 
 end = False
 
@@ -35,6 +37,22 @@ def corrPlot(iPop, select):
         mutWave = mutWave.T
     return mutWave
 
+def mutPlot(iPop, select):
+    mutWave = []
+    if select == 0:
+        mutWave = iPop[:, [1,2]].toarray().T
+    elif select == 1:
+        mutWave = np.zeros([iPop._shape[0], 2])
+        t = iPop[:, 1:iPop._shape[1]].toarray()
+        for i in range(iPop._shape[0]):
+            a = t[i, :]
+            mutWave[i,0] = sum(a[a>0])
+            mutWave[i,1] = abs(sum(a[a<0]))
+        mutWave = mutWave.T
+    elif select == 3:
+        mutWave = iPop[:,1].toarray().T[0]
+    return mutWave
+
 def commands(q, ID, iPop, file_localization, file_name, iter_outer, skip, iter_inner, cycle, tau, select):
     global end
     queue_data = q.get()
@@ -53,10 +71,12 @@ def commands(q, ID, iPop, file_localization, file_name, iter_outer, skip, iter_i
                 q.put(['0', str(ID), "unable to save file"])
             else:
                 saveToFile(iPop, file_localization, file_name, iter_outer)
-        elif(queue_data[2] == "corr_plot" and select != 3):        
+        elif(queue_data[2] == "corr_plot" and select != 3 and select != 2):        
             q.put(['-1', str(ID), corrPlot(iPop, select)])
-        elif(queue_data[2] == "mut_wave"):
-            print("TODO")
+        elif(queue_data[2] == "mut_wave" and select != 2):
+            q.put(['-2', str(ID), mutPlot(iPop, select)])
+        elif(queue_data[2] == "fit_wave" and select != 2):
+            q.put(['-2', str(ID), iPop[:,0].toarray()])
     else:
         q.put(queue_data)
  
@@ -69,7 +89,7 @@ def plotter(iPop, file_name, file_localization, iter_outer, plots, select):
     if plots & 16: 
         saveToFile(iPop, file_localization, file_name, iter_outer)
     
-def posNegEvolutionMainLoop(iPop, params, file_name="", file_description="", file_localization="", plots=0, t_iter=0, q=None, ID=0, select=0, break_type=1):
+def posNegEvolutionMainLoop(iPop, params, file_name="", file_description="", file_localization="", plots=0, t_iter=0, q=None, ID=0, select=0, break_type=0):
     global end
     """
     Main simulation loop
@@ -105,6 +125,7 @@ def posNegEvolutionMainLoop(iPop, params, file_name="", file_description="", fil
     cycle = round(skip/tau)
     
     t = time.time()
+    tx = time.time()
     clear = False
     
     while 1:   
@@ -115,16 +136,34 @@ def posNegEvolutionMainLoop(iPop, params, file_name="", file_description="", fil
         if end:
             break
 
-        if iter_inner % cycle == 0 or begin:
+        if iter_inner % (cycle/skip) == 0 or begin:
             begin = 0
             t = time.time() - t  
             print(str(ID) + ':' + str(t))
             
-            plotter(iPop, file_name, file_localization, iter_outer, plots, select)
-
-            iter_outer = iter_outer + 1   
+            if iter_outer % skip == 0:
+                plotter(iPop, file_name, file_localization, iter_outer, plots, select)
+ 
             clear = True
+            
+            if plots == 16:
+                tx = time.time() - tx
+                if not os.path.exists(file_localization + '/' + "report/"  + file_name + "_report_" + str(ID) + ".txt"):
+                    os.makedirs(file_localization + '/' + "report/", exist_ok=True)
+                    FILE = open(file_localization + '/' + "report/"  + file_name + "_report_" + str(ID) + ".txt", 'w')
+                    FILE.write("name: %s" % file_name)
+                    FILE.write('\n')
+                    FILE.write(str(ID) + ',' + str(tx))
+                    FILE.write('\n')
+                    FILE.close()
+                else:
+                    FILE = open(file_localization + '/' + "report/"  + file_name + "_report_" + str(ID) + ".txt", 'a')
+                    FILE.write(str(ID) + ',' + str(tx))
+                    FILE.write('\n')
+                    FILE.close()
+                tx = time.time()            
             t = time.time()
+            iter_outer = iter_outer + 1  
         
         if iter_outer % steps == 0 and break_type == 0:
             print('all steps')
@@ -139,7 +178,9 @@ def posNegEvolutionMainLoop(iPop, params, file_name="", file_description="", fil
             iPop = PNELV(iPop, cap, tau, mut_prob, mut_effect, resume, lmbd, threads, clear)
         elif select == 2:            
             iPop = PNAM(iPop, cap, tau, mut_prob, mut_effect, resume, lmbd, threads)
-        
+        elif select == 3:
+            iPop = PNOE(iPop, cap, tau, mut_prob, mut_effect, resume, lmbd)
+            
         resume = 0
         iter_inner = iter_inner + 1
              
\ No newline at end of file
